git.delta.rocks / unique-network / refs/commits / fb2c7d6a78b6

difftreelog

added `collectionLimits` function in `Collection` interface, changed signture for `setCollectionLimit`

PraetorP2022-12-09parent: #21ff2d2.patch.diff
in: master

15 files changed

modifiedpallets/common/src/erc.rsdiffbeforeafterboth
--- a/pallets/common/src/erc.rs
+++ b/pallets/common/src/erc.rs
@@ -37,6 +37,7 @@
 	Pallet, CollectionHandle, Config, CollectionProperties, SelfWeightOf,
 	eth::{
 		EthCrossAccount, convert_cross_account_to_uint256, CollectionPermissions as EvmPermissions,
+		CollectionLimits as EvmCollectionLimits,
 	},
 	weights::WeightInfo,
 };
@@ -304,6 +305,101 @@
 		Ok(result)
 	}
 
+	/// Get current collection limits.
+	///
+	/// @return Array of tuples (byte, bool, uint256) with limits and their values. Order of limits:
+	/// 	"accountTokenOwnershipLimit",
+	/// 	"sponsoredDataSize",
+	/// 	"sponsoredDataRateLimit",
+	/// 	"tokenLimit",
+	/// 	"sponsorTransferTimeout",
+	/// 	"sponsorApproveTimeout"
+	///  	"ownerCanTransfer",
+	/// 	"ownerCanDestroy",
+	/// 	"transfersEnabled"
+	/// Return `false` if a limit not set.
+	fn collection_limits(&self) -> Result<Vec<(EvmCollectionLimits, bool, uint256)>> {
+		let convert_value_limit = |limit: EvmCollectionLimits,
+		                           value: Option<u32>|
+		 -> (EvmCollectionLimits, bool, uint256) {
+			value
+				.map(|v| (limit, true, v.into()))
+				.unwrap_or((limit, false, Default::default()))
+		};
+
+		let convert_bool_limit = |limit: EvmCollectionLimits,
+		                          value: Option<bool>|
+		 -> (EvmCollectionLimits, bool, uint256) {
+			value
+				.map(|v| {
+					(
+						limit,
+						true,
+						if v {
+							uint256::from(1)
+						} else {
+							Default::default()
+						},
+					)
+				})
+				.unwrap_or((limit, false, Default::default()))
+		};
+
+		let limits = &self.collection.limits;
+
+		Ok(vec![
+			convert_value_limit(
+				EvmCollectionLimits::AccountTokenOwnership,
+				limits.account_token_ownership_limit,
+			),
+			convert_value_limit(
+				EvmCollectionLimits::SponsoredDataSize,
+				limits.sponsored_data_size,
+			),
+			limits
+				.sponsored_data_rate_limit
+				.map(|limit| {
+					(
+						EvmCollectionLimits::SponsoredDataRateLimit,
+						match limit {
+							SponsoringRateLimit::Blocks(_) => true,
+							_ => false,
+						},
+						match limit {
+							SponsoringRateLimit::Blocks(blocks) => blocks.into(),
+							_ => Default::default(),
+						},
+					)
+				})
+				.unwrap_or((
+					EvmCollectionLimits::SponsoredDataRateLimit,
+					false,
+					Default::default(),
+				)),
+			convert_value_limit(EvmCollectionLimits::TokenLimit, limits.token_limit),
+			convert_value_limit(
+				EvmCollectionLimits::SponsorTransferTimeout,
+				limits.sponsor_transfer_timeout,
+			),
+			convert_value_limit(
+				EvmCollectionLimits::SponsorApproveTimeout,
+				limits.sponsor_approve_timeout,
+			),
+			convert_bool_limit(
+				EvmCollectionLimits::OwnerCanTransfer,
+				limits.owner_can_transfer,
+			),
+			convert_bool_limit(
+				EvmCollectionLimits::OwnerCanDestroy,
+				limits.owner_can_destroy,
+			),
+			convert_bool_limit(
+				EvmCollectionLimits::TransferEnabled,
+				limits.transfers_enabled,
+			),
+		])
+	}
+
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
 	/// @param limit Name of the limit. Valid names:
@@ -318,9 +414,19 @@
 	/// 	"transfersEnabled"
 	/// @param value Value of the limit.
 	#[solidity(rename_selector = "setCollectionLimit")]
-	fn set_int_limit(&mut self, caller: caller, limit: string, value: uint256) -> Result<void> {
+	fn set_collection_limit(
+		&mut self,
+		caller: caller,
+		limit: EvmCollectionLimits,
+		status: bool,
+		value: uint256,
+	) -> Result<void> {
 		self.consume_store_reads_and_writes(1, 1)?;
 
+		if !status {
+			return Err(Error::Revert("user can't disable limits".into()));
+		}
+
 		let value = value
 			.try_into()
 			.map_err(|_| Error::Revert(format!("can't convert value to u32 \"{}\"", value)))?;
@@ -338,35 +444,35 @@
 
 		let mut limits = self.limits.clone();
 
-		match limit.as_str() {
-			"accountTokenOwnershipLimit" => {
+		match limit {
+			EvmCollectionLimits::AccountTokenOwnership => {
 				limits.account_token_ownership_limit = Some(value);
 			}
-			"sponsoredDataSize" => {
+			EvmCollectionLimits::SponsoredDataSize => {
 				limits.sponsored_data_size = Some(value);
 			}
-			"sponsoredDataRateLimit" => {
+			EvmCollectionLimits::SponsoredDataRateLimit => {
 				limits.sponsored_data_rate_limit = Some(SponsoringRateLimit::Blocks(value));
 			}
-			"tokenLimit" => {
+			EvmCollectionLimits::TokenLimit => {
 				limits.token_limit = Some(value);
 			}
-			"sponsorTransferTimeout" => {
+			EvmCollectionLimits::SponsorTransferTimeout => {
 				limits.sponsor_transfer_timeout = Some(value);
 			}
-			"sponsorApproveTimeout" => {
+			EvmCollectionLimits::SponsorApproveTimeout => {
 				limits.sponsor_approve_timeout = Some(value);
 			}
-			"ownerCanTransfer" => {
+			EvmCollectionLimits::OwnerCanTransfer => {
 				limits.owner_can_transfer = Some(convert_value_to_bool()?);
 			}
-			"ownerCanDestroy" => {
+			EvmCollectionLimits::OwnerCanDestroy => {
 				limits.owner_can_destroy = Some(convert_value_to_bool()?);
 			}
-			"transfersEnabled" => {
+			EvmCollectionLimits::TransferEnabled => {
 				limits.transfers_enabled = Some(convert_value_to_bool()?);
 			}
-			_ => return Err(Error::Revert(format!("unknown limit \"{}\"", limit))),
+			_ => return Err(Error::Revert(format!("unknown limit \"{:?}\"", limit))),
 		}
 
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -778,3 +884,31 @@
 		})
 	}
 }
+
+fn convert_value_limit<V: Into<uint256> + Copy>(
+	limit: EvmCollectionLimits,
+	value: &Option<V>,
+) -> (EvmCollectionLimits, bool, uint256) {
+	value
+		.map(|v| (limit, true, v.into()))
+		.unwrap_or((limit, false, Default::default()))
+}
+
+fn convert_bool_limit(
+	limit: EvmCollectionLimits,
+	value: &Option<bool>,
+) -> (EvmCollectionLimits, bool, uint256) {
+	value
+		.map(|v| {
+			(
+				limit,
+				true,
+				if v {
+					uint256::from(1)
+				} else {
+					Default::default()
+				},
+			)
+		})
+		.unwrap_or((limit, false, Default::default()))
+}
modifiedpallets/common/src/eth.rsdiffbeforeafterboth
--- a/pallets/common/src/eth.rs
+++ b/pallets/common/src/eth.rs
@@ -155,6 +155,20 @@
 		}
 	}
 }
+#[derive(Debug, Default, Clone, Copy, AbiCoder)]
+#[repr(u8)]
+pub enum CollectionLimits {
+	#[default]
+	AccountTokenOwnership,
+	SponsoredDataSize,
+	SponsoredDataRateLimit,
+	TokenLimit,
+	SponsorTransferTimeout,
+	SponsorApproveTimeout,
+	OwnerCanTransfer,
+	OwnerCanDestroy,
+	TransferEnabled,
+}
 #[derive(Default, Debug, Clone, Copy, AbiCoder)]
 #[repr(u8)]
 pub enum CollectionPermissions {
modifiedpallets/fungible/src/stubs/UniqueFungible.soldiffbeforeafterboth
before · pallets/fungible/src/stubs/UniqueFungible.sol
1// SPDX-License-Identifier: OTHER2// This code is automatically generated34pragma solidity >=0.8.0 <0.9.0;56/// @dev common stubs holder7contract Dummy {8	uint8 dummy;9	string stub_error = "this contract is implemented in native";10}1112contract ERC165 is Dummy {13	function supportsInterface(bytes4 interfaceID) external view returns (bool) {14		require(false, stub_error);15		interfaceID;16		return true;17	}18}1920/// @title A contract that allows you to work with collections.21/// @dev the ERC-165 identifier for this interface is 0xb5e1747f22contract Collection is Dummy, ERC165 {23	// /// Set collection property.24	// ///25	// /// @param key Property key.26	// /// @param value Propery value.27	// /// @dev EVM selector for this function is: 0x2f073f66,28	// ///  or in textual repr: setCollectionProperty(string,bytes)29	// function setCollectionProperty(string memory key, bytes memory value) public {30	// 	require(false, stub_error);31	// 	key;32	// 	value;33	// 	dummy = 0;34	// }3536	/// Set collection properties.37	///38	/// @param properties Vector of properties key/value pair.39	/// @dev EVM selector for this function is: 0x50b26b2a,40	///  or in textual repr: setCollectionProperties((string,bytes)[])41	function setCollectionProperties(Property[] memory properties) public {42		require(false, stub_error);43		properties;44		dummy = 0;45	}4647	// /// Delete collection property.48	// ///49	// /// @param key Property key.50	// /// @dev EVM selector for this function is: 0x7b7debce,51	// ///  or in textual repr: deleteCollectionProperty(string)52	// function deleteCollectionProperty(string memory key) public {53	// 	require(false, stub_error);54	// 	key;55	// 	dummy = 0;56	// }5758	/// Delete collection properties.59	///60	/// @param keys Properties keys.61	/// @dev EVM selector for this function is: 0xee206ee3,62	///  or in textual repr: deleteCollectionProperties(string[])63	function deleteCollectionProperties(string[] memory keys) public {64		require(false, stub_error);65		keys;66		dummy = 0;67	}6869	/// Get collection property.70	///71	/// @dev Throws error if key not found.72	///73	/// @param key Property key.74	/// @return bytes The property corresponding to the key.75	/// @dev EVM selector for this function is: 0xcf24fd6d,76	///  or in textual repr: collectionProperty(string)77	function collectionProperty(string memory key) public view returns (bytes memory) {78		require(false, stub_error);79		key;80		dummy;81		return hex"";82	}8384	/// Get collection properties.85	///86	/// @param keys Properties keys. Empty keys for all propertyes.87	/// @return Vector of properties key/value pairs.88	/// @dev EVM selector for this function is: 0x285fb8e6,89	///  or in textual repr: collectionProperties(string[])90	function collectionProperties(string[] memory keys) public view returns (Property[] memory) {91		require(false, stub_error);92		keys;93		dummy;94		return new Property[](0);95	}9697	// /// Set the sponsor of the collection.98	// ///99	// /// @dev In order for sponsorship to work, it must be confirmed on behalf of the sponsor.100	// ///101	// /// @param sponsor Address of the sponsor from whose account funds will be debited for operations with the contract.102	// /// @dev EVM selector for this function is: 0x7623402e,103	// ///  or in textual repr: setCollectionSponsor(address)104	// function setCollectionSponsor(address sponsor) public {105	// 	require(false, stub_error);106	// 	sponsor;107	// 	dummy = 0;108	// }109110	/// Set the sponsor of the collection.111	///112	/// @dev In order for sponsorship to work, it must be confirmed on behalf of the sponsor.113	///114	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.115	/// @dev EVM selector for this function is: 0x84a1d5a8,116	///  or in textual repr: setCollectionSponsorCross((address,uint256))117	function setCollectionSponsorCross(EthCrossAccount memory sponsor) public {118		require(false, stub_error);119		sponsor;120		dummy = 0;121	}122123	/// Whether there is a pending sponsor.124	/// @dev EVM selector for this function is: 0x058ac185,125	///  or in textual repr: hasCollectionPendingSponsor()126	function hasCollectionPendingSponsor() public view returns (bool) {127		require(false, stub_error);128		dummy;129		return false;130	}131132	/// Collection sponsorship confirmation.133	///134	/// @dev After setting the sponsor for the collection, it must be confirmed with this function.135	/// @dev EVM selector for this function is: 0x3c50e97a,136	///  or in textual repr: confirmCollectionSponsorship()137	function confirmCollectionSponsorship() public {138		require(false, stub_error);139		dummy = 0;140	}141142	/// Remove collection sponsor.143	/// @dev EVM selector for this function is: 0x6e0326a3,144	///  or in textual repr: removeCollectionSponsor()145	function removeCollectionSponsor() public {146		require(false, stub_error);147		dummy = 0;148	}149150	/// Get current sponsor.151	///152	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.153	/// @dev EVM selector for this function is: 0x6ec0a9f1,154	///  or in textual repr: collectionSponsor()155	function collectionSponsor() public view returns (Tuple8 memory) {156		require(false, stub_error);157		dummy;158		return Tuple8(0x0000000000000000000000000000000000000000, 0);159	}160161	/// Set limits for the collection.162	/// @dev Throws error if limit not found.163	/// @param limit Name of the limit. Valid names:164	/// 	"accountTokenOwnershipLimit",165	/// 	"sponsoredDataSize",166	/// 	"sponsoredDataRateLimit",167	/// 	"tokenLimit",168	/// 	"sponsorTransferTimeout",169	/// 	"sponsorApproveTimeout"170	///  	"ownerCanTransfer",171	/// 	"ownerCanDestroy",172	/// 	"transfersEnabled"173	/// @param value Value of the limit.174	/// @dev EVM selector for this function is: 0x4ad890a8,175	///  or in textual repr: setCollectionLimit(string,uint256)176	function setCollectionLimit(string memory limit, uint256 value) public {177		require(false, stub_error);178		limit;179		value;180		dummy = 0;181	}182183	/// Get contract address.184	/// @dev EVM selector for this function is: 0xf6b4dfb4,185	///  or in textual repr: contractAddress()186	function contractAddress() public view returns (address) {187		require(false, stub_error);188		dummy;189		return 0x0000000000000000000000000000000000000000;190	}191192	/// Add collection admin.193	/// @param newAdmin Cross account administrator address.194	/// @dev EVM selector for this function is: 0x859aa7d6,195	///  or in textual repr: addCollectionAdminCross((address,uint256))196	function addCollectionAdminCross(EthCrossAccount memory newAdmin) public {197		require(false, stub_error);198		newAdmin;199		dummy = 0;200	}201202	/// Remove collection admin.203	/// @param admin Cross account administrator address.204	/// @dev EVM selector for this function is: 0x6c0cd173,205	///  or in textual repr: removeCollectionAdminCross((address,uint256))206	function removeCollectionAdminCross(EthCrossAccount memory admin) public {207		require(false, stub_error);208		admin;209		dummy = 0;210	}211212	// /// Add collection admin.213	// /// @param newAdmin Address of the added administrator.214	// /// @dev EVM selector for this function is: 0x92e462c7,215	// ///  or in textual repr: addCollectionAdmin(address)216	// function addCollectionAdmin(address newAdmin) public {217	// 	require(false, stub_error);218	// 	newAdmin;219	// 	dummy = 0;220	// }221222	// /// Remove collection admin.223	// ///224	// /// @param admin Address of the removed administrator.225	// /// @dev EVM selector for this function is: 0xfafd7b42,226	// ///  or in textual repr: removeCollectionAdmin(address)227	// function removeCollectionAdmin(address admin) public {228	// 	require(false, stub_error);229	// 	admin;230	// 	dummy = 0;231	// }232233	/// Toggle accessibility of collection nesting.234	///235	/// @param enable If "true" degenerates to nesting: 'Owner' else to nesting: 'Disabled'236	/// @dev EVM selector for this function is: 0x112d4586,237	///  or in textual repr: setCollectionNesting(bool)238	function setCollectionNesting(bool enable) public {239		require(false, stub_error);240		enable;241		dummy = 0;242	}243244	/// Toggle accessibility of collection nesting.245	///246	/// @param enable If "true" degenerates to nesting: {OwnerRestricted: [1, 2, 3]} else to nesting: 'Disabled'247	/// @param collections Addresses of collections that will be available for nesting.248	/// @dev EVM selector for this function is: 0x64872396,249	///  or in textual repr: setCollectionNesting(bool,address[])250	function setCollectionNesting(bool enable, address[] memory collections) public {251		require(false, stub_error);252		enable;253		collections;254		dummy = 0;255	}256257	/// Returns nesting for a collection258	/// @dev EVM selector for this function is: 0x22d25bfe,259	///  or in textual repr: collectionNestingRestrictedCollectionIds()260	function collectionNestingRestrictedCollectionIds() public view returns (Tuple21 memory) {261		require(false, stub_error);262		dummy;263		return Tuple21(false, new uint256[](0));264	}265266	/// Returns permissions for a collection267	/// @dev EVM selector for this function is: 0x5b2eaf4b,268	///  or in textual repr: collectionNestingPermissions()269	function collectionNestingPermissions() public view returns (Tuple24[] memory) {270		require(false, stub_error);271		dummy;272		return new Tuple24[](0);273	}274275	/// Set the collection access method.276	/// @param mode Access mode277	/// 	0 for Normal278	/// 	1 for AllowList279	/// @dev EVM selector for this function is: 0x41835d4c,280	///  or in textual repr: setCollectionAccess(uint8)281	function setCollectionAccess(uint8 mode) public {282		require(false, stub_error);283		mode;284		dummy = 0;285	}286287	/// Checks that user allowed to operate with collection.288	///289	/// @param user User address to check.290	/// @dev EVM selector for this function is: 0x91b6df49,291	///  or in textual repr: allowlistedCross((address,uint256))292	function allowlistedCross(EthCrossAccount memory user) public view returns (bool) {293		require(false, stub_error);294		user;295		dummy;296		return false;297	}298299	// /// Add the user to the allowed list.300	// ///301	// /// @param user Address of a trusted user.302	// /// @dev EVM selector for this function is: 0x67844fe6,303	// ///  or in textual repr: addToCollectionAllowList(address)304	// function addToCollectionAllowList(address user) public {305	// 	require(false, stub_error);306	// 	user;307	// 	dummy = 0;308	// }309310	/// Add user to allowed list.311	///312	/// @param user User cross account address.313	/// @dev EVM selector for this function is: 0xa0184a3a,314	///  or in textual repr: addToCollectionAllowListCross((address,uint256))315	function addToCollectionAllowListCross(EthCrossAccount memory user) public {316		require(false, stub_error);317		user;318		dummy = 0;319	}320321	// /// Remove the user from the allowed list.322	// ///323	// /// @param user Address of a removed user.324	// /// @dev EVM selector for this function is: 0x85c51acb,325	// ///  or in textual repr: removeFromCollectionAllowList(address)326	// function removeFromCollectionAllowList(address user) public {327	// 	require(false, stub_error);328	// 	user;329	// 	dummy = 0;330	// }331332	/// Remove user from allowed list.333	///334	/// @param user User cross account address.335	/// @dev EVM selector for this function is: 0x09ba452a,336	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))337	function removeFromCollectionAllowListCross(EthCrossAccount memory user) public {338		require(false, stub_error);339		user;340		dummy = 0;341	}342343	/// Switch permission for minting.344	///345	/// @param mode Enable if "true".346	/// @dev EVM selector for this function is: 0x00018e84,347	///  or in textual repr: setCollectionMintMode(bool)348	function setCollectionMintMode(bool mode) public {349		require(false, stub_error);350		mode;351		dummy = 0;352	}353354	// /// Check that account is the owner or admin of the collection355	// ///356	// /// @param user account to verify357	// /// @return "true" if account is the owner or admin358	// /// @dev EVM selector for this function is: 0x9811b0c7,359	// ///  or in textual repr: isOwnerOrAdmin(address)360	// function isOwnerOrAdmin(address user) public view returns (bool) {361	// 	require(false, stub_error);362	// 	user;363	// 	dummy;364	// 	return false;365	// }366367	/// Check that account is the owner or admin of the collection368	///369	/// @param user User cross account to verify370	/// @return "true" if account is the owner or admin371	/// @dev EVM selector for this function is: 0x3e75a905,372	///  or in textual repr: isOwnerOrAdminCross((address,uint256))373	function isOwnerOrAdminCross(EthCrossAccount memory user) public view returns (bool) {374		require(false, stub_error);375		user;376		dummy;377		return false;378	}379380	/// Returns collection type381	///382	/// @return `Fungible` or `NFT` or `ReFungible`383	/// @dev EVM selector for this function is: 0xd34b55b8,384	///  or in textual repr: uniqueCollectionType()385	function uniqueCollectionType() public view returns (string memory) {386		require(false, stub_error);387		dummy;388		return "";389	}390391	/// Get collection owner.392	///393	/// @return Tuble with sponsor address and his substrate mirror.394	/// If address is canonical then substrate mirror is zero and vice versa.395	/// @dev EVM selector for this function is: 0xdf727d3b,396	///  or in textual repr: collectionOwner()397	function collectionOwner() public view returns (EthCrossAccount memory) {398		require(false, stub_error);399		dummy;400		return EthCrossAccount(0x0000000000000000000000000000000000000000, 0);401	}402403	// /// Changes collection owner to another account404	// ///405	// /// @dev Owner can be changed only by current owner406	// /// @param newOwner new owner account407	// /// @dev EVM selector for this function is: 0x4f53e226,408	// ///  or in textual repr: changeCollectionOwner(address)409	// function changeCollectionOwner(address newOwner) public {410	// 	require(false, stub_error);411	// 	newOwner;412	// 	dummy = 0;413	// }414415	/// Get collection administrators416	///417	/// @return Vector of tuples with admins address and his substrate mirror.418	/// If address is canonical then substrate mirror is zero and vice versa.419	/// @dev EVM selector for this function is: 0x5813216b,420	///  or in textual repr: collectionAdmins()421	function collectionAdmins() public view returns (EthCrossAccount[] memory) {422		require(false, stub_error);423		dummy;424		return new EthCrossAccount[](0);425	}426427	/// Changes collection owner to another account428	///429	/// @dev Owner can be changed only by current owner430	/// @param newOwner new owner cross account431	/// @dev EVM selector for this function is: 0x6496c497,432	///  or in textual repr: changeCollectionOwnerCross((address,uint256))433	function changeCollectionOwnerCross(EthCrossAccount memory newOwner) public {434		require(false, stub_error);435		newOwner;436		dummy = 0;437	}438}439440/// @dev Cross account struct441struct EthCrossAccount {442	address eth;443	uint256 sub;444}445446enum CollectionPermissions {447	CollectionAdmin,448	TokenOwner449}450451/// @dev anonymous struct452struct Tuple24 {453	CollectionPermissions field_0;454	bool field_1;455}456457/// @dev anonymous struct458struct Tuple21 {459	bool field_0;460	uint256[] field_1;461}462463/// @dev Property struct464struct Property {465	string key;466	bytes value;467}468469/// @dev the ERC-165 identifier for this interface is 0x5b7038cf470contract ERC20UniqueExtensions is Dummy, ERC165 {471	/// @notice A description for the collection.472	/// @dev EVM selector for this function is: 0x7284e416,473	///  or in textual repr: description()474	function description() public view returns (string memory) {475		require(false, stub_error);476		dummy;477		return "";478	}479480	/// @dev EVM selector for this function is: 0x0ecd0ab0,481	///  or in textual repr: approveCross((address,uint256),uint256)482	function approveCross(EthCrossAccount memory spender, uint256 amount) public returns (bool) {483		require(false, stub_error);484		spender;485		amount;486		dummy = 0;487		return false;488	}489490	// /// Burn tokens from account491	// /// @dev Function that burns an `amount` of the tokens of a given account,492	// /// deducting from the sender's allowance for said account.493	// /// @param from The account whose tokens will be burnt.494	// /// @param amount The amount that will be burnt.495	// /// @dev EVM selector for this function is: 0x79cc6790,496	// ///  or in textual repr: burnFrom(address,uint256)497	// function burnFrom(address from, uint256 amount) public returns (bool) {498	// 	require(false, stub_error);499	// 	from;500	// 	amount;501	// 	dummy = 0;502	// 	return false;503	// }504505	/// Burn tokens from account506	/// @dev Function that burns an `amount` of the tokens of a given account,507	/// deducting from the sender's allowance for said account.508	/// @param from The account whose tokens will be burnt.509	/// @param amount The amount that will be burnt.510	/// @dev EVM selector for this function is: 0xbb2f5a58,511	///  or in textual repr: burnFromCross((address,uint256),uint256)512	function burnFromCross(EthCrossAccount memory from, uint256 amount) public returns (bool) {513		require(false, stub_error);514		from;515		amount;516		dummy = 0;517		return false;518	}519520	/// Mint tokens for multiple accounts.521	/// @param amounts array of pairs of account address and amount522	/// @dev EVM selector for this function is: 0x1acf2d55,523	///  or in textual repr: mintBulk((address,uint256)[])524	function mintBulk(Tuple8[] memory amounts) public returns (bool) {525		require(false, stub_error);526		amounts;527		dummy = 0;528		return false;529	}530531	/// @dev EVM selector for this function is: 0x2ada85ff,532	///  or in textual repr: transferCross((address,uint256),uint256)533	function transferCross(EthCrossAccount memory to, uint256 amount) public returns (bool) {534		require(false, stub_error);535		to;536		amount;537		dummy = 0;538		return false;539	}540541	/// @dev EVM selector for this function is: 0xd5cf430b,542	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)543	function transferFromCross(544		EthCrossAccount memory from,545		EthCrossAccount memory to,546		uint256 amount547	) public returns (bool) {548		require(false, stub_error);549		from;550		to;551		amount;552		dummy = 0;553		return false;554	}555}556557/// @dev anonymous struct558struct Tuple8 {559	address field_0;560	uint256 field_1;561}562563/// @dev the ERC-165 identifier for this interface is 0x40c10f19564contract ERC20Mintable is Dummy, ERC165 {565	/// Mint tokens for `to` account.566	/// @param to account that will receive minted tokens567	/// @param amount amount of tokens to mint568	/// @dev EVM selector for this function is: 0x40c10f19,569	///  or in textual repr: mint(address,uint256)570	function mint(address to, uint256 amount) public returns (bool) {571		require(false, stub_error);572		to;573		amount;574		dummy = 0;575		return false;576	}577}578579/// @dev inlined interface580contract ERC20Events {581	event Transfer(address indexed from, address indexed to, uint256 value);582	event Approval(address indexed owner, address indexed spender, uint256 value);583}584585/// @dev the ERC-165 identifier for this interface is 0x8cb847c4586contract ERC20 is Dummy, ERC165, ERC20Events {587	/// @dev EVM selector for this function is: 0x06fdde03,588	///  or in textual repr: name()589	function name() public view returns (string memory) {590		require(false, stub_error);591		dummy;592		return "";593	}594595	/// @dev EVM selector for this function is: 0x95d89b41,596	///  or in textual repr: symbol()597	function symbol() public view returns (string memory) {598		require(false, stub_error);599		dummy;600		return "";601	}602603	/// @dev EVM selector for this function is: 0x18160ddd,604	///  or in textual repr: totalSupply()605	function totalSupply() public view returns (uint256) {606		require(false, stub_error);607		dummy;608		return 0;609	}610611	/// @dev EVM selector for this function is: 0x313ce567,612	///  or in textual repr: decimals()613	function decimals() public view returns (uint8) {614		require(false, stub_error);615		dummy;616		return 0;617	}618619	/// @dev EVM selector for this function is: 0x70a08231,620	///  or in textual repr: balanceOf(address)621	function balanceOf(address owner) public view returns (uint256) {622		require(false, stub_error);623		owner;624		dummy;625		return 0;626	}627628	/// @dev EVM selector for this function is: 0xa9059cbb,629	///  or in textual repr: transfer(address,uint256)630	function transfer(address to, uint256 amount) public returns (bool) {631		require(false, stub_error);632		to;633		amount;634		dummy = 0;635		return false;636	}637638	/// @dev EVM selector for this function is: 0x23b872dd,639	///  or in textual repr: transferFrom(address,address,uint256)640	function transferFrom(641		address from,642		address to,643		uint256 amount644	) public returns (bool) {645		require(false, stub_error);646		from;647		to;648		amount;649		dummy = 0;650		return false;651	}652653	/// @dev EVM selector for this function is: 0x095ea7b3,654	///  or in textual repr: approve(address,uint256)655	function approve(address spender, uint256 amount) public returns (bool) {656		require(false, stub_error);657		spender;658		amount;659		dummy = 0;660		return false;661	}662663	/// @dev EVM selector for this function is: 0xdd62ed3e,664	///  or in textual repr: allowance(address,address)665	function allowance(address owner, address spender) public view returns (uint256) {666		require(false, stub_error);667		owner;668		spender;669		dummy;670		return 0;671	}672673	/// @notice Returns collection helper contract address674	/// @dev EVM selector for this function is: 0x1896cce6,675	///  or in textual repr: collectionHelperAddress()676	function collectionHelperAddress() public view returns (address) {677		require(false, stub_error);678		dummy;679		return 0x0000000000000000000000000000000000000000;680	}681}682683contract UniqueFungible is Dummy, ERC165, ERC20, ERC20Mintable, ERC20UniqueExtensions, Collection {}
after · pallets/fungible/src/stubs/UniqueFungible.sol
1// SPDX-License-Identifier: OTHER2// This code is automatically generated34pragma solidity >=0.8.0 <0.9.0;56/// @dev common stubs holder7contract Dummy {8	uint8 dummy;9	string stub_error = "this contract is implemented in native";10}1112contract ERC165 is Dummy {13	function supportsInterface(bytes4 interfaceID) external view returns (bool) {14		require(false, stub_error);15		interfaceID;16		return true;17	}18}1920/// @title A contract that allows you to work with collections.21/// @dev the ERC-165 identifier for this interface is 0xb5e1747f22contract Collection is Dummy, ERC165 {23	// /// Set collection property.24	// ///25	// /// @param key Property key.26	// /// @param value Propery value.27	// /// @dev EVM selector for this function is: 0x2f073f66,28	// ///  or in textual repr: setCollectionProperty(string,bytes)29	// function setCollectionProperty(string memory key, bytes memory value) public {30	// 	require(false, stub_error);31	// 	key;32	// 	value;33	// 	dummy = 0;34	// }3536	/// Set collection properties.37	///38	/// @param properties Vector of properties key/value pair.39	/// @dev EVM selector for this function is: 0x50b26b2a,40	///  or in textual repr: setCollectionProperties((string,bytes)[])41	function setCollectionProperties(Property[] memory properties) public {42		require(false, stub_error);43		properties;44		dummy = 0;45	}4647	// /// Delete collection property.48	// ///49	// /// @param key Property key.50	// /// @dev EVM selector for this function is: 0x7b7debce,51	// ///  or in textual repr: deleteCollectionProperty(string)52	// function deleteCollectionProperty(string memory key) public {53	// 	require(false, stub_error);54	// 	key;55	// 	dummy = 0;56	// }5758	/// Delete collection properties.59	///60	/// @param keys Properties keys.61	/// @dev EVM selector for this function is: 0xee206ee3,62	///  or in textual repr: deleteCollectionProperties(string[])63	function deleteCollectionProperties(string[] memory keys) public {64		require(false, stub_error);65		keys;66		dummy = 0;67	}6869	/// Get collection property.70	///71	/// @dev Throws error if key not found.72	///73	/// @param key Property key.74	/// @return bytes The property corresponding to the key.75	/// @dev EVM selector for this function is: 0xcf24fd6d,76	///  or in textual repr: collectionProperty(string)77	function collectionProperty(string memory key) public view returns (bytes memory) {78		require(false, stub_error);79		key;80		dummy;81		return hex"";82	}8384	/// Get collection properties.85	///86	/// @param keys Properties keys. Empty keys for all propertyes.87	/// @return Vector of properties key/value pairs.88	/// @dev EVM selector for this function is: 0x285fb8e6,89	///  or in textual repr: collectionProperties(string[])90	function collectionProperties(string[] memory keys) public view returns (Property[] memory) {91		require(false, stub_error);92		keys;93		dummy;94		return new Property[](0);95	}9697	// /// Set the sponsor of the collection.98	// ///99	// /// @dev In order for sponsorship to work, it must be confirmed on behalf of the sponsor.100	// ///101	// /// @param sponsor Address of the sponsor from whose account funds will be debited for operations with the contract.102	// /// @dev EVM selector for this function is: 0x7623402e,103	// ///  or in textual repr: setCollectionSponsor(address)104	// function setCollectionSponsor(address sponsor) public {105	// 	require(false, stub_error);106	// 	sponsor;107	// 	dummy = 0;108	// }109110	/// Set the sponsor of the collection.111	///112	/// @dev In order for sponsorship to work, it must be confirmed on behalf of the sponsor.113	///114	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.115	/// @dev EVM selector for this function is: 0x84a1d5a8,116	///  or in textual repr: setCollectionSponsorCross((address,uint256))117	function setCollectionSponsorCross(EthCrossAccount memory sponsor) public {118		require(false, stub_error);119		sponsor;120		dummy = 0;121	}122123	/// Whether there is a pending sponsor.124	/// @dev EVM selector for this function is: 0x058ac185,125	///  or in textual repr: hasCollectionPendingSponsor()126	function hasCollectionPendingSponsor() public view returns (bool) {127		require(false, stub_error);128		dummy;129		return false;130	}131132	/// Collection sponsorship confirmation.133	///134	/// @dev After setting the sponsor for the collection, it must be confirmed with this function.135	/// @dev EVM selector for this function is: 0x3c50e97a,136	///  or in textual repr: confirmCollectionSponsorship()137	function confirmCollectionSponsorship() public {138		require(false, stub_error);139		dummy = 0;140	}141142	/// Remove collection sponsor.143	/// @dev EVM selector for this function is: 0x6e0326a3,144	///  or in textual repr: removeCollectionSponsor()145	function removeCollectionSponsor() public {146		require(false, stub_error);147		dummy = 0;148	}149150	/// Get current sponsor.151	///152	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.153	/// @dev EVM selector for this function is: 0x6ec0a9f1,154	///  or in textual repr: collectionSponsor()155	function collectionSponsor() public view returns (Tuple8 memory) {156		require(false, stub_error);157		dummy;158		return Tuple8(0x0000000000000000000000000000000000000000, 0);159	}160161	/// Get current collection limits.162	///163	/// @return Array of tuples (byte, bool, uint256) with limits and their values. Order of limits:164	/// 	"accountTokenOwnershipLimit",165	/// 	"sponsoredDataSize",166	/// 	"sponsoredDataRateLimit",167	/// 	"tokenLimit",168	/// 	"sponsorTransferTimeout",169	/// 	"sponsorApproveTimeout"170	///  	"ownerCanTransfer",171	/// 	"ownerCanDestroy",172	/// 	"transfersEnabled"173	/// Return `false` if a limit not set.174	/// @dev EVM selector for this function is: 0xf63bc572,175	///  or in textual repr: collectionLimits()176	function collectionLimits() public view returns (Tuple20[] memory) {177		require(false, stub_error);178		dummy;179		return new Tuple20[](0);180	}181182	/// Set limits for the collection.183	/// @dev Throws error if limit not found.184	/// @param limit Name of the limit. Valid names:185	/// 	"accountTokenOwnershipLimit",186	/// 	"sponsoredDataSize",187	/// 	"sponsoredDataRateLimit",188	/// 	"tokenLimit",189	/// 	"sponsorTransferTimeout",190	/// 	"sponsorApproveTimeout"191	///  	"ownerCanTransfer",192	/// 	"ownerCanDestroy",193	/// 	"transfersEnabled"194	/// @param value Value of the limit.195	/// @dev EVM selector for this function is: 0x88150bd0,196	///  or in textual repr: setCollectionLimit(uint8,bool,uint256)197	function setCollectionLimit(198		CollectionLimits limit,199		bool status,200		uint256 value201	) public {202		require(false, stub_error);203		limit;204		status;205		value;206		dummy = 0;207	}208209	/// Get contract address.210	/// @dev EVM selector for this function is: 0xf6b4dfb4,211	///  or in textual repr: contractAddress()212	function contractAddress() public view returns (address) {213		require(false, stub_error);214		dummy;215		return 0x0000000000000000000000000000000000000000;216	}217218	/// Add collection admin.219	/// @param newAdmin Cross account administrator address.220	/// @dev EVM selector for this function is: 0x859aa7d6,221	///  or in textual repr: addCollectionAdminCross((address,uint256))222	function addCollectionAdminCross(EthCrossAccount memory newAdmin) public {223		require(false, stub_error);224		newAdmin;225		dummy = 0;226	}227228	/// Remove collection admin.229	/// @param admin Cross account administrator address.230	/// @dev EVM selector for this function is: 0x6c0cd173,231	///  or in textual repr: removeCollectionAdminCross((address,uint256))232	function removeCollectionAdminCross(EthCrossAccount memory admin) public {233		require(false, stub_error);234		admin;235		dummy = 0;236	}237238	// /// Add collection admin.239	// /// @param newAdmin Address of the added administrator.240	// /// @dev EVM selector for this function is: 0x92e462c7,241	// ///  or in textual repr: addCollectionAdmin(address)242	// function addCollectionAdmin(address newAdmin) public {243	// 	require(false, stub_error);244	// 	newAdmin;245	// 	dummy = 0;246	// }247248	// /// Remove collection admin.249	// ///250	// /// @param admin Address of the removed administrator.251	// /// @dev EVM selector for this function is: 0xfafd7b42,252	// ///  or in textual repr: removeCollectionAdmin(address)253	// function removeCollectionAdmin(address admin) public {254	// 	require(false, stub_error);255	// 	admin;256	// 	dummy = 0;257	// }258259	/// Toggle accessibility of collection nesting.260	///261	/// @param enable If "true" degenerates to nesting: 'Owner' else to nesting: 'Disabled'262	/// @dev EVM selector for this function is: 0x112d4586,263	///  or in textual repr: setCollectionNesting(bool)264	function setCollectionNesting(bool enable) public {265		require(false, stub_error);266		enable;267		dummy = 0;268	}269270	/// Toggle accessibility of collection nesting.271	///272	/// @param enable If "true" degenerates to nesting: {OwnerRestricted: [1, 2, 3]} else to nesting: 'Disabled'273	/// @param collections Addresses of collections that will be available for nesting.274	/// @dev EVM selector for this function is: 0x64872396,275	///  or in textual repr: setCollectionNesting(bool,address[])276	function setCollectionNesting(bool enable, address[] memory collections) public {277		require(false, stub_error);278		enable;279		collections;280		dummy = 0;281	}282283	/// Returns nesting for a collection284	/// @dev EVM selector for this function is: 0x22d25bfe,285	///  or in textual repr: collectionNestingRestrictedCollectionIds()286	function collectionNestingRestrictedCollectionIds() public view returns (Tuple21 memory) {287		require(false, stub_error);288		dummy;289		return Tuple21(false, new uint256[](0));290	}291292	/// Returns permissions for a collection293	/// @dev EVM selector for this function is: 0x5b2eaf4b,294	///  or in textual repr: collectionNestingPermissions()295	function collectionNestingPermissions() public view returns (Tuple24[] memory) {296		require(false, stub_error);297		dummy;298		return new Tuple24[](0);299	}300301	/// Set the collection access method.302	/// @param mode Access mode303	/// 	0 for Normal304	/// 	1 for AllowList305	/// @dev EVM selector for this function is: 0x41835d4c,306	///  or in textual repr: setCollectionAccess(uint8)307	function setCollectionAccess(uint8 mode) public {308		require(false, stub_error);309		mode;310		dummy = 0;311	}312313	/// Checks that user allowed to operate with collection.314	///315	/// @param user User address to check.316	/// @dev EVM selector for this function is: 0x91b6df49,317	///  or in textual repr: allowlistedCross((address,uint256))318	function allowlistedCross(EthCrossAccount memory user) public view returns (bool) {319		require(false, stub_error);320		user;321		dummy;322		return false;323	}324325	// /// Add the user to the allowed list.326	// ///327	// /// @param user Address of a trusted user.328	// /// @dev EVM selector for this function is: 0x67844fe6,329	// ///  or in textual repr: addToCollectionAllowList(address)330	// function addToCollectionAllowList(address user) public {331	// 	require(false, stub_error);332	// 	user;333	// 	dummy = 0;334	// }335336	/// Add user to allowed list.337	///338	/// @param user User cross account address.339	/// @dev EVM selector for this function is: 0xa0184a3a,340	///  or in textual repr: addToCollectionAllowListCross((address,uint256))341	function addToCollectionAllowListCross(EthCrossAccount memory user) public {342		require(false, stub_error);343		user;344		dummy = 0;345	}346347	// /// Remove the user from the allowed list.348	// ///349	// /// @param user Address of a removed user.350	// /// @dev EVM selector for this function is: 0x85c51acb,351	// ///  or in textual repr: removeFromCollectionAllowList(address)352	// function removeFromCollectionAllowList(address user) public {353	// 	require(false, stub_error);354	// 	user;355	// 	dummy = 0;356	// }357358	/// Remove user from allowed list.359	///360	/// @param user User cross account address.361	/// @dev EVM selector for this function is: 0x09ba452a,362	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))363	function removeFromCollectionAllowListCross(EthCrossAccount memory user) public {364		require(false, stub_error);365		user;366		dummy = 0;367	}368369	/// Switch permission for minting.370	///371	/// @param mode Enable if "true".372	/// @dev EVM selector for this function is: 0x00018e84,373	///  or in textual repr: setCollectionMintMode(bool)374	function setCollectionMintMode(bool mode) public {375		require(false, stub_error);376		mode;377		dummy = 0;378	}379380	// /// Check that account is the owner or admin of the collection381	// ///382	// /// @param user account to verify383	// /// @return "true" if account is the owner or admin384	// /// @dev EVM selector for this function is: 0x9811b0c7,385	// ///  or in textual repr: isOwnerOrAdmin(address)386	// function isOwnerOrAdmin(address user) public view returns (bool) {387	// 	require(false, stub_error);388	// 	user;389	// 	dummy;390	// 	return false;391	// }392393	/// Check that account is the owner or admin of the collection394	///395	/// @param user User cross account to verify396	/// @return "true" if account is the owner or admin397	/// @dev EVM selector for this function is: 0x3e75a905,398	///  or in textual repr: isOwnerOrAdminCross((address,uint256))399	function isOwnerOrAdminCross(EthCrossAccount memory user) public view returns (bool) {400		require(false, stub_error);401		user;402		dummy;403		return false;404	}405406	/// Returns collection type407	///408	/// @return `Fungible` or `NFT` or `ReFungible`409	/// @dev EVM selector for this function is: 0xd34b55b8,410	///  or in textual repr: uniqueCollectionType()411	function uniqueCollectionType() public view returns (string memory) {412		require(false, stub_error);413		dummy;414		return "";415	}416417	/// Get collection owner.418	///419	/// @return Tuble with sponsor address and his substrate mirror.420	/// If address is canonical then substrate mirror is zero and vice versa.421	/// @dev EVM selector for this function is: 0xdf727d3b,422	///  or in textual repr: collectionOwner()423	function collectionOwner() public view returns (EthCrossAccount memory) {424		require(false, stub_error);425		dummy;426		return EthCrossAccount(0x0000000000000000000000000000000000000000, 0);427	}428429	// /// Changes collection owner to another account430	// ///431	// /// @dev Owner can be changed only by current owner432	// /// @param newOwner new owner account433	// /// @dev EVM selector for this function is: 0x4f53e226,434	// ///  or in textual repr: changeCollectionOwner(address)435	// function changeCollectionOwner(address newOwner) public {436	// 	require(false, stub_error);437	// 	newOwner;438	// 	dummy = 0;439	// }440441	/// Get collection administrators442	///443	/// @return Vector of tuples with admins address and his substrate mirror.444	/// If address is canonical then substrate mirror is zero and vice versa.445	/// @dev EVM selector for this function is: 0x5813216b,446	///  or in textual repr: collectionAdmins()447	function collectionAdmins() public view returns (EthCrossAccount[] memory) {448		require(false, stub_error);449		dummy;450		return new EthCrossAccount[](0);451	}452453	/// Changes collection owner to another account454	///455	/// @dev Owner can be changed only by current owner456	/// @param newOwner new owner cross account457	/// @dev EVM selector for this function is: 0x6496c497,458	///  or in textual repr: changeCollectionOwnerCross((address,uint256))459	function changeCollectionOwnerCross(EthCrossAccount memory newOwner) public {460		require(false, stub_error);461		newOwner;462		dummy = 0;463	}464}465466/// @dev Cross account struct467struct EthCrossAccount {468	address eth;469	uint256 sub;470}471472enum CollectionPermissions {473	CollectionAdmin,474	TokenOwner475}476477/// @dev anonymous struct478struct Tuple24 {479	CollectionPermissions field_0;480	bool field_1;481}482483/// @dev anonymous struct484struct Tuple21 {485	bool field_0;486	uint256[] field_1;487}488489/// @dev Property struct490struct Property {491	string key;492	bytes value;493}494495/// @dev the ERC-165 identifier for this interface is 0x5b7038cf496contract ERC20UniqueExtensions is Dummy, ERC165 {497	/// @notice A description for the collection.498	/// @dev EVM selector for this function is: 0x7284e416,499	///  or in textual repr: description()500	function description() public view returns (string memory) {501		require(false, stub_error);502		dummy;503		return "";504	}505506	/// @dev EVM selector for this function is: 0x0ecd0ab0,507	///  or in textual repr: approveCross((address,uint256),uint256)508	function approveCross(EthCrossAccount memory spender, uint256 amount) public returns (bool) {509		require(false, stub_error);510		spender;511		amount;512		dummy = 0;513		return false;514	}515516	// /// Burn tokens from account517	// /// @dev Function that burns an `amount` of the tokens of a given account,518	// /// deducting from the sender's allowance for said account.519	// /// @param from The account whose tokens will be burnt.520	// /// @param amount The amount that will be burnt.521	// /// @dev EVM selector for this function is: 0x79cc6790,522	// ///  or in textual repr: burnFrom(address,uint256)523	// function burnFrom(address from, uint256 amount) public returns (bool) {524	// 	require(false, stub_error);525	// 	from;526	// 	amount;527	// 	dummy = 0;528	// 	return false;529	// }530531	/// Burn tokens from account532	/// @dev Function that burns an `amount` of the tokens of a given account,533	/// deducting from the sender's allowance for said account.534	/// @param from The account whose tokens will be burnt.535	/// @param amount The amount that will be burnt.536	/// @dev EVM selector for this function is: 0xbb2f5a58,537	///  or in textual repr: burnFromCross((address,uint256),uint256)538	function burnFromCross(EthCrossAccount memory from, uint256 amount) public returns (bool) {539		require(false, stub_error);540		from;541		amount;542		dummy = 0;543		return false;544	}545546	/// Mint tokens for multiple accounts.547	/// @param amounts array of pairs of account address and amount548	/// @dev EVM selector for this function is: 0x1acf2d55,549	///  or in textual repr: mintBulk((address,uint256)[])550	function mintBulk(Tuple8[] memory amounts) public returns (bool) {551		require(false, stub_error);552		amounts;553		dummy = 0;554		return false;555	}556557	/// @dev EVM selector for this function is: 0x2ada85ff,558	///  or in textual repr: transferCross((address,uint256),uint256)559	function transferCross(EthCrossAccount memory to, uint256 amount) public returns (bool) {560		require(false, stub_error);561		to;562		amount;563		dummy = 0;564		return false;565	}566567	/// @dev EVM selector for this function is: 0xd5cf430b,568	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)569	function transferFromCross(570		EthCrossAccount memory from,571		EthCrossAccount memory to,572		uint256 amount573	) public returns (bool) {574		require(false, stub_error);575		from;576		to;577		amount;578		dummy = 0;579		return false;580	}581}582583/// @dev anonymous struct584struct Tuple8 {585	address field_0;586	uint256 field_1;587}588589/// @dev the ERC-165 identifier for this interface is 0x40c10f19590contract ERC20Mintable is Dummy, ERC165 {591	/// Mint tokens for `to` account.592	/// @param to account that will receive minted tokens593	/// @param amount amount of tokens to mint594	/// @dev EVM selector for this function is: 0x40c10f19,595	///  or in textual repr: mint(address,uint256)596	function mint(address to, uint256 amount) public returns (bool) {597		require(false, stub_error);598		to;599		amount;600		dummy = 0;601		return false;602	}603}604605/// @dev inlined interface606contract ERC20Events {607	event Transfer(address indexed from, address indexed to, uint256 value);608	event Approval(address indexed owner, address indexed spender, uint256 value);609}610611/// @dev the ERC-165 identifier for this interface is 0x8cb847c4612contract ERC20 is Dummy, ERC165, ERC20Events {613	/// @dev EVM selector for this function is: 0x06fdde03,614	///  or in textual repr: name()615	function name() public view returns (string memory) {616		require(false, stub_error);617		dummy;618		return "";619	}620621	/// @dev EVM selector for this function is: 0x95d89b41,622	///  or in textual repr: symbol()623	function symbol() public view returns (string memory) {624		require(false, stub_error);625		dummy;626		return "";627	}628629	/// @dev EVM selector for this function is: 0x18160ddd,630	///  or in textual repr: totalSupply()631	function totalSupply() public view returns (uint256) {632		require(false, stub_error);633		dummy;634		return 0;635	}636637	/// @dev EVM selector for this function is: 0x313ce567,638	///  or in textual repr: decimals()639	function decimals() public view returns (uint8) {640		require(false, stub_error);641		dummy;642		return 0;643	}644645	/// @dev EVM selector for this function is: 0x70a08231,646	///  or in textual repr: balanceOf(address)647	function balanceOf(address owner) public view returns (uint256) {648		require(false, stub_error);649		owner;650		dummy;651		return 0;652	}653654	/// @dev EVM selector for this function is: 0xa9059cbb,655	///  or in textual repr: transfer(address,uint256)656	function transfer(address to, uint256 amount) public returns (bool) {657		require(false, stub_error);658		to;659		amount;660		dummy = 0;661		return false;662	}663664	/// @dev EVM selector for this function is: 0x23b872dd,665	///  or in textual repr: transferFrom(address,address,uint256)666	function transferFrom(667		address from,668		address to,669		uint256 amount670	) public returns (bool) {671		require(false, stub_error);672		from;673		to;674		amount;675		dummy = 0;676		return false;677	}678679	/// @dev EVM selector for this function is: 0x095ea7b3,680	///  or in textual repr: approve(address,uint256)681	function approve(address spender, uint256 amount) public returns (bool) {682		require(false, stub_error);683		spender;684		amount;685		dummy = 0;686		return false;687	}688689	/// @dev EVM selector for this function is: 0xdd62ed3e,690	///  or in textual repr: allowance(address,address)691	function allowance(address owner, address spender) public view returns (uint256) {692		require(false, stub_error);693		owner;694		spender;695		dummy;696		return 0;697	}698699	/// @notice Returns collection helper contract address700	/// @dev EVM selector for this function is: 0x1896cce6,701	///  or in textual repr: collectionHelperAddress()702	function collectionHelperAddress() public view returns (address) {703		require(false, stub_error);704		dummy;705		return 0x0000000000000000000000000000000000000000;706	}707}708709contract UniqueFungible is Dummy, ERC165, ERC20, ERC20Mintable, ERC20UniqueExtensions, Collection {}
modifiedpallets/nonfungible/src/stubs/UniqueNFT.soldiffbeforeafterboth
--- a/tests/src/eth/abi/fungible.json
+++ b/tests/src/eth/abi/fungible.json
@@ -208,11 +208,16 @@
   },
   {
     "inputs": [],
+<<<<<<< HEAD
     "name": "collectionNestingPermissions",
+=======
+    "name": "collectionLimits",
+>>>>>>> 32e011ce... added `collectionLimits` function in `Collection` interface,  changed signture for `setCollectionLimit`
     "outputs": [
       {
         "components": [
           {
+<<<<<<< HEAD
             "internalType": "enum CollectionPermissions",
             "name": "field_0",
             "type": "uint8"
@@ -220,6 +225,16 @@
           { "internalType": "bool", "name": "field_1", "type": "bool" }
         ],
         "internalType": "struct Tuple24[]",
+=======
+            "internalType": "enum CollectionLimits",
+            "name": "field_0",
+            "type": "uint8"
+          },
+          { "internalType": "bool", "name": "field_1", "type": "bool" },
+          { "internalType": "uint256", "name": "field_2", "type": "uint256" }
+        ],
+        "internalType": "struct Tuple20[]",
+>>>>>>> 32e011ce... added `collectionLimits` function in `Collection` interface,  changed signture for `setCollectionLimit`
         "name": "",
         "type": "tuple[]"
       }
@@ -229,6 +244,7 @@
   },
   {
     "inputs": [],
+<<<<<<< HEAD
     "name": "collectionNestingRestrictedCollectionIds",
     "outputs": [
       {
@@ -250,6 +266,8 @@
   },
   {
     "inputs": [],
+=======
+>>>>>>> 32e011ce... added `collectionLimits` function in `Collection` interface,  changed signture for `setCollectionLimit`
     "name": "collectionOwner",
     "outputs": [
       {
@@ -453,7 +471,12 @@
   },
   {
     "inputs": [
-      { "internalType": "string", "name": "limit", "type": "string" },
+      {
+        "internalType": "enum CollectionLimits",
+        "name": "limit",
+        "type": "uint8"
+      },
+      { "internalType": "bool", "name": "status", "type": "bool" },
       { "internalType": "uint256", "name": "value", "type": "uint256" }
     ],
     "name": "setCollectionLimit",
modifiedtests/src/eth/abi/nonFungible.jsondiffbeforeafterboth
--- a/tests/src/eth/abi/nonFungible.json
+++ b/tests/src/eth/abi/nonFungible.json
@@ -607,7 +607,12 @@
   },
   {
     "inputs": [
-      { "internalType": "string", "name": "limit", "type": "string" },
+      {
+        "internalType": "enum CollectionLimits",
+        "name": "limit",
+        "type": "uint8"
+      },
+      { "internalType": "bool", "name": "status", "type": "bool" },
       { "internalType": "uint256", "name": "value", "type": "uint256" }
     ],
     "name": "setCollectionLimit",
modifiedtests/src/eth/abi/reFungible.jsondiffbeforeafterboth
--- a/tests/src/eth/abi/reFungible.json
+++ b/tests/src/eth/abi/reFungible.json
@@ -589,7 +589,12 @@
   },
   {
     "inputs": [
-      { "internalType": "string", "name": "limit", "type": "string" },
+      {
+        "internalType": "enum CollectionLimits",
+        "name": "limit",
+        "type": "uint8"
+      },
+      { "internalType": "bool", "name": "status", "type": "bool" },
       { "internalType": "uint256", "name": "value", "type": "uint256" }
     ],
     "name": "setCollectionLimit",
modifiedtests/src/eth/api/UniqueFungible.soldiffbeforeafterboth
--- a/tests/src/eth/createFTCollection.test.ts
+++ b/tests/src/eth/createFTCollection.test.ts
@@ -17,7 +17,7 @@
 import {IKeyringPair} from '@polkadot/types/types';
 import {evmToAddress} from '@polkadot/util-crypto';
 import {Pallets, requirePalletsOrSkip} from '../util';
-import {expect, itEth, usingEthPlaygrounds} from './util';
+import {CollectionLimits, expect, itEth, usingEthPlaygrounds} from './util';
 
 const DECIMALS = 18;
 
@@ -79,6 +79,56 @@
     expect(await collection.methods.description().call()).to.deep.equal(description);
   });
 
+  itEth('Set limits', async ({helper}) => {
+    const owner = await helper.eth.createAccountWithBalance(donor);
+    const {collectionId, collectionAddress} = await helper.eth.createFungibleCollection(owner, 'Limits', DECIMALS, 'absolutely anything', 'INSI');
+    const limits = {
+      accountTokenOwnershipLimit: 1000,
+      sponsoredDataSize: 1024,
+      sponsoredDataRateLimit: 30,
+      tokenLimit: 1000000,
+      sponsorTransferTimeout: 6,
+      sponsorApproveTimeout: 6,
+      ownerCanTransfer: 0,
+      ownerCanDestroy: 0,
+      transfersEnabled: 0,
+    };
+    
+    const expectedLimits = {
+      accountTokenOwnershipLimit: 1000,
+      sponsoredDataSize: 1024,
+      sponsoredDataRateLimit: 30,
+      tokenLimit: 1000000,
+      sponsorTransferTimeout: 6,
+      sponsorApproveTimeout: 6,
+      ownerCanTransfer: false,
+      ownerCanDestroy: false,
+      transfersEnabled: false,
+    };
+   
+    const collection = helper.ethNativeContract.collection(collectionAddress, 'ft', owner);
+    await collection.methods.setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, limits.accountTokenOwnershipLimit).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsoredDataSize, true, limits.sponsoredDataSize).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsoredDataRateLimit, true, limits.sponsoredDataRateLimit).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.TokenLimit, true, limits.tokenLimit).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsorTransferTimeout, true, limits.sponsorTransferTimeout).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsorApproveTimeout, true, limits.sponsorApproveTimeout).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.OwnerCanTransfer, true, limits.ownerCanTransfer).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.OwnerCanDestroy, true, limits.ownerCanDestroy).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.TransferEnabled, true, limits.transfersEnabled).send();
+    
+    const data = (await helper.rft.getData(collectionId))!;
+    expect(data.raw.limits.accountTokenOwnershipLimit).to.be.eq(expectedLimits.accountTokenOwnershipLimit);
+    expect(data.raw.limits.sponsoredDataSize).to.be.eq(expectedLimits.sponsoredDataSize);
+    expect(data.raw.limits.sponsoredDataRateLimit.blocks).to.be.eq(expectedLimits.sponsoredDataRateLimit);
+    expect(data.raw.limits.tokenLimit).to.be.eq(expectedLimits.tokenLimit);
+    expect(data.raw.limits.sponsorTransferTimeout).to.be.eq(expectedLimits.sponsorTransferTimeout);
+    expect(data.raw.limits.sponsorApproveTimeout).to.be.eq(expectedLimits.sponsorApproveTimeout);
+    expect(data.raw.limits.ownerCanTransfer).to.be.eq(expectedLimits.ownerCanTransfer);
+    expect(data.raw.limits.ownerCanDestroy).to.be.eq(expectedLimits.ownerCanDestroy);
+    expect(data.raw.limits.transfersEnabled).to.be.eq(expectedLimits.transfersEnabled);
+  });
+
   itEth('Collection address exist', async ({helper}) => {
     const owner = await helper.eth.createAccountWithBalance(donor);
     const collectionAddressForNonexistentCollection = '0x17C4E6453CC49AAAAEACA894E6D9683E00112233';
@@ -197,6 +247,7 @@
     {
       await expect(peasantCollection.methods
         .setCollectionLimit('accountTokenOwnershipLimit', '1000')
+        .setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, 1000)
         .call()).to.be.rejectedWith(EXPECTED_ERROR);
     }
   });
@@ -224,5 +275,31 @@
         .setCollectionLimit('accountTokenOwnershipLimit', '1000')
         .call()).to.be.rejectedWith(EXPECTED_ERROR);
     }
-  });    
+  });
+
+  itEth('(!negative test!) Set limits', async ({helper}) => {
+
+    const invalidLimits = {
+      accountTokenOwnershipLimit: BigInt(Number.MAX_SAFE_INTEGER),
+      transfersEnabled: 3,
+    };
+
+    const owner = await helper.eth.createAccountWithBalance(donor);
+    const {collectionAddress} = await helper.eth.createFungibleCollection(owner, 'Limits', DECIMALS, 'absolutely anything', 'ISNI');
+    const collectionEvm = helper.ethNativeContract.collection(collectionAddress, 'ft', owner);
+    await expect(collectionEvm.methods
+      .setCollectionLimit(20, true, '1')
+      .call()).to.be.rejectedWith('Returned error: VM Exception while processing transaction: revert Value not convertible into enum "CollectionLimits"');
+    
+    await expect(collectionEvm.methods
+      .setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, invalidLimits.accountTokenOwnershipLimit)
+      .call()).to.be.rejectedWith(`can't convert value to u32 "${invalidLimits.accountTokenOwnershipLimit}"`);
+    
+    await expect(collectionEvm.methods
+      .setCollectionLimit(CollectionLimits.TransferEnabled, true, invalidLimits.transfersEnabled)
+      .call()).to.be.rejectedWith(`can't convert value to boolean "${invalidLimits.transfersEnabled}"`);
+  });
+
+   
+    
 });
modifiedtests/src/eth/createNFTCollection.test.tsdiffbeforeafterboth
--- a/tests/src/eth/createNFTCollection.test.ts
+++ b/tests/src/eth/createNFTCollection.test.ts
@@ -16,7 +16,7 @@
 
 import {evmToAddress} from '@polkadot/util-crypto';
 import {IKeyringPair} from '@polkadot/types/types';
-import {expect, itEth, usingEthPlaygrounds} from './util';
+import {CollectionLimits, expect, itEth, usingEthPlaygrounds} from './util';
 
 
 describe('Create NFT collection from EVM', () => {
@@ -120,6 +120,56 @@
     expect(await sponsorCollection.methods.description().call()).to.deep.equal(description);
   });
 
+  itEth('Set limits', async ({helper}) => {
+    const owner = await helper.eth.createAccountWithBalance(donor);
+    const {collectionId, collectionAddress} = await helper.eth.createNFTCollection(owner, 'Limits', 'absolutely anything', 'FLO');
+    const limits = {
+      accountTokenOwnershipLimit: 1000,
+      sponsoredDataSize: 1024,
+      sponsoredDataRateLimit: 30,
+      tokenLimit: 1000000,
+      sponsorTransferTimeout: 6,
+      sponsorApproveTimeout: 6,
+      ownerCanTransfer: 0,
+      ownerCanDestroy: 0,
+      transfersEnabled: 0,
+    };
+    
+    const expectedLimits = {
+      accountTokenOwnershipLimit: 1000,
+      sponsoredDataSize: 1024,
+      sponsoredDataRateLimit: 30,
+      tokenLimit: 1000000,
+      sponsorTransferTimeout: 6,
+      sponsorApproveTimeout: 6,
+      ownerCanTransfer: false,
+      ownerCanDestroy: false,
+      transfersEnabled: false,
+    };
+
+    const collection = helper.ethNativeContract.collection(collectionAddress, 'nft', owner);
+    await collection.methods.setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, limits.accountTokenOwnershipLimit).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsoredDataSize, true, limits.sponsoredDataSize).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsoredDataRateLimit, true, limits.sponsoredDataRateLimit).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.TokenLimit, true, limits.tokenLimit).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsorTransferTimeout, true, limits.sponsorTransferTimeout).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsorApproveTimeout, true, limits.sponsorApproveTimeout).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.OwnerCanTransfer, true, limits.ownerCanTransfer).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.OwnerCanDestroy, true, limits.ownerCanDestroy).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.TransferEnabled, true, limits.transfersEnabled).send();
+
+    const data = (await helper.rft.getData(collectionId))!;
+    expect(data.raw.limits.accountTokenOwnershipLimit).to.be.eq(expectedLimits.accountTokenOwnershipLimit);
+    expect(data.raw.limits.sponsoredDataSize).to.be.eq(expectedLimits.sponsoredDataSize);
+    expect(data.raw.limits.sponsoredDataRateLimit.blocks).to.be.eq(expectedLimits.sponsoredDataRateLimit);
+    expect(data.raw.limits.tokenLimit).to.be.eq(expectedLimits.tokenLimit);
+    expect(data.raw.limits.sponsorTransferTimeout).to.be.eq(expectedLimits.sponsorTransferTimeout);
+    expect(data.raw.limits.sponsorApproveTimeout).to.be.eq(expectedLimits.sponsorApproveTimeout);
+    expect(data.raw.limits.ownerCanTransfer).to.be.eq(expectedLimits.ownerCanTransfer);
+    expect(data.raw.limits.ownerCanDestroy).to.be.eq(expectedLimits.ownerCanDestroy);
+    expect(data.raw.limits.transfersEnabled).to.be.eq(expectedLimits.transfersEnabled);
+  });
+
   itEth('Collection address exist', async ({helper}) => {
     const owner = await helper.eth.createAccountWithBalance(donor);
     const collectionAddressForNonexistentCollection = '0x17C4E6453CC49AAAAEACA894E6D9683E00112233';
@@ -207,7 +257,7 @@
     }
     {
       await expect(malfeasantCollection.methods
-        .setCollectionLimit('accountTokenOwnershipLimit', '1000')
+        .setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, 1000)
         .call()).to.be.rejectedWith(EXPECTED_ERROR);
     }
   });
@@ -232,11 +282,30 @@
     }
     {
       await expect(malfeasantCollection.methods
-        .setCollectionLimit('accountTokenOwnershipLimit', '1000')
+        .setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, 1000)
         .call()).to.be.rejectedWith(EXPECTED_ERROR);
     }
   });
 
+  itEth('(!negative test!) Set limits', async ({helper}) => {
+    const invalidLimits = {
+      accountTokenOwnershipLimit: BigInt(Number.MAX_SAFE_INTEGER),
+      transfersEnabled: 3,
+    };
+
+    const owner = await helper.eth.createAccountWithBalance(donor);
+    const {collectionAddress} = await helper.eth.createNFTCollection(owner, 'Limits', 'absolutely anything', 'OLF');
+    const collectionEvm = helper.ethNativeContract.collection(collectionAddress, 'nft', owner);
+    
+    await expect(collectionEvm.methods
+      .setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, invalidLimits.accountTokenOwnershipLimit)
+      .call()).to.be.rejectedWith(`can't convert value to u32 "${invalidLimits.accountTokenOwnershipLimit}"`);
+    
+    await expect(collectionEvm.methods
+      .setCollectionLimit(CollectionLimits.TransferEnabled, true, invalidLimits.transfersEnabled)
+      .call()).to.be.rejectedWith(`can't convert value to boolean "${invalidLimits.transfersEnabled}"`);
+  });
+
   itEth('destroyCollection', async ({helper}) => {
     const owner = await helper.eth.createAccountWithBalance(donor);
     const {collectionAddress, collectionId} = await helper.eth.createNFTCollection(owner, 'Limits', 'absolutely anything', 'OLF');
modifiedtests/src/eth/createRFTCollection.test.tsdiffbeforeafterboth
--- a/tests/src/eth/createRFTCollection.test.ts
+++ b/tests/src/eth/createRFTCollection.test.ts
@@ -17,7 +17,7 @@
 import {evmToAddress} from '@polkadot/util-crypto';
 import {IKeyringPair} from '@polkadot/types/types';
 import {Pallets, requirePalletsOrSkip} from '../util';
-import {expect, itEth, usingEthPlaygrounds} from './util';
+import {CollectionLimits, expect, itEth, usingEthPlaygrounds} from './util';
 
 
 describe('Create RFT collection from EVM', () => {
@@ -152,6 +152,56 @@
     expect(data.raw.sponsorship.Confirmed).to.be.equal(evmToAddress(sponsor, Number(ss58Format)));
   });
 
+  itEth('Set limits', async ({helper}) => {
+    const owner = await helper.eth.createAccountWithBalance(donor);
+    const {collectionId, collectionAddress} = await helper.eth.createRFTCollection(owner, 'Limits', 'absolutely anything', 'INSI');
+    const limits = {
+      accountTokenOwnershipLimit: 1000,
+      sponsoredDataSize: 1024,
+      sponsoredDataRateLimit: 30,
+      tokenLimit: 1000000,
+      sponsorTransferTimeout: 6,
+      sponsorApproveTimeout: 6,
+      ownerCanTransfer: 0,
+      ownerCanDestroy: 0,
+      transfersEnabled: 0,
+    };
+    
+    const expectedLimits = {
+      accountTokenOwnershipLimit: 1000,
+      sponsoredDataSize: 1024,
+      sponsoredDataRateLimit: 30,
+      tokenLimit: 1000000,
+      sponsorTransferTimeout: 6,
+      sponsorApproveTimeout: 6,
+      ownerCanTransfer: false,
+      ownerCanDestroy: false,
+      transfersEnabled: false,
+    };
+    
+    const collection = helper.ethNativeContract.collection(collectionAddress, 'rft', owner);
+    await collection.methods.setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, limits.accountTokenOwnershipLimit).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsoredDataSize, true, limits.sponsoredDataSize).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsoredDataRateLimit, true, limits.sponsoredDataRateLimit).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.TokenLimit, true, limits.tokenLimit).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsorTransferTimeout, true, limits.sponsorTransferTimeout).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.SponsorApproveTimeout, true, limits.sponsorApproveTimeout).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.OwnerCanTransfer, true, limits.ownerCanTransfer).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.OwnerCanDestroy, true, limits.ownerCanDestroy).send();
+    await collection.methods.setCollectionLimit(CollectionLimits.TransferEnabled, true, limits.transfersEnabled).send();
+    
+    const data = (await helper.rft.getData(collectionId))!;
+    expect(data.raw.limits.accountTokenOwnershipLimit).to.be.eq(expectedLimits.accountTokenOwnershipLimit);
+    expect(data.raw.limits.sponsoredDataSize).to.be.eq(expectedLimits.sponsoredDataSize);
+    expect(data.raw.limits.sponsoredDataRateLimit.blocks).to.be.eq(expectedLimits.sponsoredDataRateLimit);
+    expect(data.raw.limits.tokenLimit).to.be.eq(expectedLimits.tokenLimit);
+    expect(data.raw.limits.sponsorTransferTimeout).to.be.eq(expectedLimits.sponsorTransferTimeout);
+    expect(data.raw.limits.sponsorApproveTimeout).to.be.eq(expectedLimits.sponsorApproveTimeout);
+    expect(data.raw.limits.ownerCanTransfer).to.be.eq(expectedLimits.ownerCanTransfer);
+    expect(data.raw.limits.ownerCanDestroy).to.be.eq(expectedLimits.ownerCanDestroy);
+    expect(data.raw.limits.transfersEnabled).to.be.eq(expectedLimits.transfersEnabled);
+  });
+
   itEth('Collection address exist', async ({helper}) => {
     const owner = await helper.eth.createAccountWithBalance(donor);
     const collectionAddressForNonexistentCollection = '0x17C4E6453CC49AAAAEACA894E6D9683E00112233';
@@ -239,7 +289,7 @@
     }
     {
       await expect(peasantCollection.methods
-        .setCollectionLimit('accountTokenOwnershipLimit', '1000')
+        .setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, 1000)
         .call()).to.be.rejectedWith(EXPECTED_ERROR);
     }
   });
@@ -264,10 +314,29 @@
     }
     {
       await expect(peasantCollection.methods
-        .setCollectionLimit('accountTokenOwnershipLimit', '1000')
+        .setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, 1000)
         .call()).to.be.rejectedWith(EXPECTED_ERROR);
     }
   });
+
+  itEth('(!negative test!) Set limits', async ({helper}) => {
+    const invalidLimits = {
+      accountTokenOwnershipLimit: BigInt(Number.MAX_SAFE_INTEGER),
+      transfersEnabled: 3,
+    };
+
+    const owner = await helper.eth.createAccountWithBalance(donor);
+    const {collectionAddress} = await helper.eth.createRFTCollection(owner, 'Limits', 'absolutely anything', 'ISNI');
+    const collectionEvm = helper.ethNativeContract.collection(collectionAddress, 'rft', owner);
+    
+    await expect(collectionEvm.methods
+      .setCollectionLimit(CollectionLimits.AccountTokenOwnership, true, invalidLimits.accountTokenOwnershipLimit)
+      .call()).to.be.rejectedWith(`can't convert value to u32 "${invalidLimits.accountTokenOwnershipLimit}"`);
+    
+    await expect(collectionEvm.methods
+      .setCollectionLimit(CollectionLimits.TransferEnabled, true, invalidLimits.transfersEnabled)
+      .call()).to.be.rejectedWith(`can't convert value to boolean "${invalidLimits.transfersEnabled}"`);
+  });
   
   itEth('destroyCollection', async ({helper}) => {
     const owner = await helper.eth.createAccountWithBalance(donor);
modifiedtests/src/eth/util/index.tsdiffbeforeafterboth
--- a/tests/src/eth/util/index.ts
+++ b/tests/src/eth/util/index.ts
@@ -26,6 +26,17 @@
   Allowlisted = 1,
   Generous = 2,
 }
+export enum CollectionLimits {
+  AccountTokenOwnership,
+	SponsoredDataSize,
+	SponsoredDataRateLimit,
+	TokenLimit,
+	SponsorTransferTimeout,
+	SponsorApproveTimeout,
+	OwnerCanTransfer,
+	OwnerCanDestroy,
+	TransferEnabled
+}
 
 export const usingEthPlaygrounds = async (code: (helper: EthUniqueHelper, privateKey: (seed: string | {filename: string}) => Promise<IKeyringPair>) => Promise<void>) => {
   const silentConsole = new SilentConsole();
--- a/pallets/nonfungible/src/stubs/UniqueNFT.sol
+++ b/pallets/nonfungible/src/stubs/UniqueNFT.sol
@@ -291,6 +291,27 @@
 		return Tuple30(0x0000000000000000000000000000000000000000, 0);
 	}
 
+	/// Get current collection limits.
+	///
+	/// @return Array of tuples (byte, bool, uint256) with limits and their values. Order of limits:
+	/// 	"accountTokenOwnershipLimit",
+	/// 	"sponsoredDataSize",
+	/// 	"sponsoredDataRateLimit",
+	/// 	"tokenLimit",
+	/// 	"sponsorTransferTimeout",
+	/// 	"sponsorApproveTimeout"
+	///  	"ownerCanTransfer",
+	/// 	"ownerCanDestroy",
+	/// 	"transfersEnabled"
+	/// Return `false` if a limit not set.
+	/// @dev EVM selector for this function is: 0xf63bc572,
+	///  or in textual repr: collectionLimits()
+	function collectionLimits() public view returns (Tuple33[] memory) {
+		require(false, stub_error);
+		dummy;
+		return new Tuple33[](0);
+	}
+
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
 	/// @param limit Name of the limit. Valid names:
@@ -304,11 +325,16 @@
 	/// 	"ownerCanDestroy",
 	/// 	"transfersEnabled"
 	/// @param value Value of the limit.
-	/// @dev EVM selector for this function is: 0x4ad890a8,
-	///  or in textual repr: setCollectionLimit(string,uint256)
-	function setCollectionLimit(string memory limit, uint256 value) public {
+	/// @dev EVM selector for this function is: 0x88150bd0,
+	///  or in textual repr: setCollectionLimit(uint8,bool,uint256)
+	function setCollectionLimit(
+		CollectionLimits limit,
+		bool status,
+		uint256 value
+	) public {
 		require(false, stub_error);
 		limit;
+		status;
 		value;
 		dummy = 0;
 	}
modifiedpallets/refungible/src/stubs/UniqueRefungible.soldiffbeforeafterboth
--- a/pallets/refungible/src/stubs/UniqueRefungible.sol
+++ b/pallets/refungible/src/stubs/UniqueRefungible.sol
@@ -292,6 +292,27 @@
 		return Tuple29(0x0000000000000000000000000000000000000000, 0);
 	}
 
+	/// Get current collection limits.
+	///
+	/// @return Array of tuples (byte, bool, uint256) with limits and their values. Order of limits:
+	/// 	"accountTokenOwnershipLimit",
+	/// 	"sponsoredDataSize",
+	/// 	"sponsoredDataRateLimit",
+	/// 	"tokenLimit",
+	/// 	"sponsorTransferTimeout",
+	/// 	"sponsorApproveTimeout"
+	///  	"ownerCanTransfer",
+	/// 	"ownerCanDestroy",
+	/// 	"transfersEnabled"
+	/// Return `false` if a limit not set.
+	/// @dev EVM selector for this function is: 0xf63bc572,
+	///  or in textual repr: collectionLimits()
+	function collectionLimits() public view returns (Tuple32[] memory) {
+		require(false, stub_error);
+		dummy;
+		return new Tuple32[](0);
+	}
+
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
 	/// @param limit Name of the limit. Valid names:
@@ -305,11 +326,16 @@
 	/// 	"ownerCanDestroy",
 	/// 	"transfersEnabled"
 	/// @param value Value of the limit.
-	/// @dev EVM selector for this function is: 0x4ad890a8,
-	///  or in textual repr: setCollectionLimit(string,uint256)
-	function setCollectionLimit(string memory limit, uint256 value) public {
+	/// @dev EVM selector for this function is: 0x88150bd0,
+	///  or in textual repr: setCollectionLimit(uint8,bool,uint256)
+	function setCollectionLimit(
+		CollectionLimits limit,
+		bool status,
+		uint256 value
+	) public {
 		require(false, stub_error);
 		limit;
+		status;
 		value;
 		dummy = 0;
 	}
modifiedtests/src/eth/abi/fungible.jsondiffbeforeafterboth
--- a/tests/src/eth/api/UniqueFungible.sol
+++ b/tests/src/eth/api/UniqueFungible.sol
@@ -13,7 +13,11 @@
 }
 
 /// @title A contract that allows you to work with collections.
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0xb5e1747f
+=======
+/// @dev the ERC-165 identifier for this interface is 0xf8ebdec0
+>>>>>>> 32e011ce... added `collectionLimits` function in `Collection` interface,  changed signture for `setCollectionLimit`
 interface Collection is Dummy, ERC165 {
 	// /// Set collection property.
 	// ///
@@ -104,6 +108,23 @@
 	///  or in textual repr: collectionSponsor()
 	function collectionSponsor() external view returns (Tuple8 memory);
 
+	/// Get current collection limits.
+	///
+	/// @return Array of tuples (byte, bool, uint256) with limits and their values. Order of limits:
+	/// 	"accountTokenOwnershipLimit",
+	/// 	"sponsoredDataSize",
+	/// 	"sponsoredDataRateLimit",
+	/// 	"tokenLimit",
+	/// 	"sponsorTransferTimeout",
+	/// 	"sponsorApproveTimeout"
+	///  	"ownerCanTransfer",
+	/// 	"ownerCanDestroy",
+	/// 	"transfersEnabled"
+	/// Return `false` if a limit not set.
+	/// @dev EVM selector for this function is: 0xf63bc572,
+	///  or in textual repr: collectionLimits()
+	function collectionLimits() external view returns (Tuple19[] memory);
+
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
 	/// @param limit Name of the limit. Valid names:
@@ -117,9 +138,13 @@
 	/// 	"ownerCanDestroy",
 	/// 	"transfersEnabled"
 	/// @param value Value of the limit.
-	/// @dev EVM selector for this function is: 0x4ad890a8,
-	///  or in textual repr: setCollectionLimit(string,uint256)
-	function setCollectionLimit(string memory limit, uint256 value) external;
+	/// @dev EVM selector for this function is: 0x88150bd0,
+	///  or in textual repr: setCollectionLimit(uint8,bool,uint256)
+	function setCollectionLimit(
+		CollectionLimits limit,
+		bool status,
+		uint256 value
+	) external;
 
 	/// Get contract address.
 	/// @dev EVM selector for this function is: 0xf6b4dfb4,
@@ -288,6 +313,7 @@
 	uint256 sub;
 }
 
+<<<<<<< HEAD
 /// @dev anonymous struct
 struct Tuple23 {
 	CollectionPermissions field_0;
@@ -303,6 +329,25 @@
 struct Tuple20 {
 	bool field_0;
 	uint256[] field_1;
+=======
+enum CollectionLimits {
+	AccountTokenOwnership,
+	SponsoredDataSize,
+	SponsoredDataRateLimit,
+	TokenLimit,
+	SponsorTransferTimeout,
+	SponsorApproveTimeout,
+	OwnerCanTransfer,
+	OwnerCanDestroy,
+	TransferEnabled
+}
+
+/// @dev anonymous struct
+struct Tuple19 {
+	CollectionLimits field_0;
+	bool field_1;
+	uint256 field_2;
+>>>>>>> 32e011ce... added `collectionLimits` function in `Collection` interface,  changed signture for `setCollectionLimit`
 }
 
 /// @dev Property struct
modifiedtests/src/eth/api/UniqueNFT.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueNFT.sol
+++ b/tests/src/eth/api/UniqueNFT.sol
@@ -104,7 +104,11 @@
 }
 
 /// @title A contract that allows you to work with collections.
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0xb5e1747f
+=======
+/// @dev the ERC-165 identifier for this interface is 0xf8ebdec0
+>>>>>>> 32e011ce... added `collectionLimits` function in `Collection` interface,  changed signture for `setCollectionLimit`
 interface Collection is Dummy, ERC165 {
 	// /// Set collection property.
 	// ///
@@ -195,6 +199,23 @@
 	///  or in textual repr: collectionSponsor()
 	function collectionSponsor() external view returns (Tuple27 memory);
 
+	/// Get current collection limits.
+	///
+	/// @return Array of tuples (byte, bool, uint256) with limits and their values. Order of limits:
+	/// 	"accountTokenOwnershipLimit",
+	/// 	"sponsoredDataSize",
+	/// 	"sponsoredDataRateLimit",
+	/// 	"tokenLimit",
+	/// 	"sponsorTransferTimeout",
+	/// 	"sponsorApproveTimeout"
+	///  	"ownerCanTransfer",
+	/// 	"ownerCanDestroy",
+	/// 	"transfersEnabled"
+	/// Return `false` if a limit not set.
+	/// @dev EVM selector for this function is: 0xf63bc572,
+	///  or in textual repr: collectionLimits()
+	function collectionLimits() external view returns (Tuple30[] memory);
+
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
 	/// @param limit Name of the limit. Valid names:
@@ -208,9 +229,13 @@
 	/// 	"ownerCanDestroy",
 	/// 	"transfersEnabled"
 	/// @param value Value of the limit.
-	/// @dev EVM selector for this function is: 0x4ad890a8,
-	///  or in textual repr: setCollectionLimit(string,uint256)
-	function setCollectionLimit(string memory limit, uint256 value) external;
+	/// @dev EVM selector for this function is: 0x88150bd0,
+	///  or in textual repr: setCollectionLimit(uint8,bool,uint256)
+	function setCollectionLimit(
+		CollectionLimits limit,
+		bool status,
+		uint256 value
+	) external;
 
 	/// Get contract address.
 	/// @dev EVM selector for this function is: 0xf6b4dfb4,
@@ -379,6 +404,25 @@
 	uint256 sub;
 }
 
+enum CollectionLimits {
+	AccountTokenOwnership,
+	SponsoredDataSize,
+	SponsoredDataRateLimit,
+	TokenLimit,
+	SponsorTransferTimeout,
+	SponsorApproveTimeout,
+	OwnerCanTransfer,
+	OwnerCanDestroy,
+	TransferEnabled
+}
+
+/// @dev anonymous struct
+struct Tuple30 {
+	CollectionLimits field_0;
+	bool field_1;
+	uint256 field_2;
+}
+
 /// @dev anonymous struct
 struct Tuple34 {
 	CollectionPermissions field_0;
modifiedtests/src/eth/api/UniqueRefungible.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueRefungible.sol
+++ b/tests/src/eth/api/UniqueRefungible.sol
@@ -105,7 +105,11 @@
 }
 
 /// @title A contract that allows you to work with collections.
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0xb5e1747f
+=======
+/// @dev the ERC-165 identifier for this interface is 0xf8ebdec0
+>>>>>>> 32e011ce... added `collectionLimits` function in `Collection` interface,  changed signture for `setCollectionLimit`
 interface Collection is Dummy, ERC165 {
 	// /// Set collection property.
 	// ///
@@ -196,6 +200,23 @@
 	///  or in textual repr: collectionSponsor()
 	function collectionSponsor() external view returns (Tuple26 memory);
 
+	/// Get current collection limits.
+	///
+	/// @return Array of tuples (byte, bool, uint256) with limits and their values. Order of limits:
+	/// 	"accountTokenOwnershipLimit",
+	/// 	"sponsoredDataSize",
+	/// 	"sponsoredDataRateLimit",
+	/// 	"tokenLimit",
+	/// 	"sponsorTransferTimeout",
+	/// 	"sponsorApproveTimeout"
+	///  	"ownerCanTransfer",
+	/// 	"ownerCanDestroy",
+	/// 	"transfersEnabled"
+	/// Return `false` if a limit not set.
+	/// @dev EVM selector for this function is: 0xf63bc572,
+	///  or in textual repr: collectionLimits()
+	function collectionLimits() external view returns (Tuple29[] memory);
+
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
 	/// @param limit Name of the limit. Valid names:
@@ -209,9 +230,13 @@
 	/// 	"ownerCanDestroy",
 	/// 	"transfersEnabled"
 	/// @param value Value of the limit.
-	/// @dev EVM selector for this function is: 0x4ad890a8,
-	///  or in textual repr: setCollectionLimit(string,uint256)
-	function setCollectionLimit(string memory limit, uint256 value) external;
+	/// @dev EVM selector for this function is: 0x88150bd0,
+	///  or in textual repr: setCollectionLimit(uint8,bool,uint256)
+	function setCollectionLimit(
+		CollectionLimits limit,
+		bool status,
+		uint256 value
+	) external;
 
 	/// Get contract address.
 	/// @dev EVM selector for this function is: 0xf6b4dfb4,
@@ -380,6 +405,25 @@
 	uint256 sub;
 }
 
+enum CollectionLimits {
+	AccountTokenOwnership,
+	SponsoredDataSize,
+	SponsoredDataRateLimit,
+	TokenLimit,
+	SponsorTransferTimeout,
+	SponsorApproveTimeout,
+	OwnerCanTransfer,
+	OwnerCanDestroy,
+	TransferEnabled
+}
+
+/// @dev anonymous struct
+struct Tuple29 {
+	CollectionLimits field_0;
+	bool field_1;
+	uint256 field_2;
+}
+
 /// @dev anonymous struct
 struct Tuple33 {
 	CollectionPermissions field_0;
modifiedtests/src/eth/createFTCollection.test.tsdiffbeforeafterboth